function [ coh, coh_avg ] = calc_coherence( phi, psi )

%This function calculates the mutual coherence and the average mutual
%coherence for given measurement and mixing matrices.
%
%Input parameters:
%phi - measurement matrix
%psi - mixing matrix
%
%Output parameters:
%coh - mutual coherence of phi * psi
%coh_avg - average mutual coherence of phi * psi
% 
% You are very welcome to use this code. For this, clearly acknowledge 
% the source of this code, and cite the paper that describes the algorithm:
% M. Mordechay and Y. Y. Schechner, "Matrix optimization for poisson compressed
% sensing," in Proceedings of IEEE GlobalSIP, December 2014, pp.684-688.
%
% (c) Copyright Moran Mordechay 2014. The matlab code is available for 
% non-commercial use and exploration.  For commercial use contact the
% author. The author is not liable for any damages or loss that might be 
% caused by use or connection to this code. 



m = size(psi, 2);
inds = eye(m)==1;
G = abs((psi' * phi') * (phi * psi));
vec = G(inds);
norms = sqrt(vec);
G = G ./ (norms * norms');
G(inds) = 0;
coh = max(max(G));
coh_avg = sum(sum(G)) / (m^2-m);

end

